@@ -39,11 +39,11 @@ end = struct
       quickcheck_generator
       ~config:{ Test.default_config with test_count = 20 }
       ~f:(fun sequence ->
-        sequence
-        |> Sequence.to_list
-        |> List.sort ~compare
-        |> List.map ~f:sexp_of_t
-        |> List.iter ~f:print_s);
+      sequence
+      |> Sequence.to_list
+      |> List.sort ~compare
+      |> List.map ~f:sexp_of_t
+      |> List.iter ~f:print_s);
     [%expect
       {|
       Nullary
@@ -65,7 +65,8 @@ end = struct
       (N_ary (DM))
       (N_ary (L7N))
       (N_ary (bAW6zR `y7O 1V7))
-      (N_ary ("\219\171nqZ" "asa\250Y")) |}]
+      (N_ary ("\219\171nqZ" "asa\250Y"))
+      |}]
   ;;
 end
 
@@ -100,13 +101,13 @@ end = struct
       quickcheck_generator
       ~config:{ Test.default_config with test_count = 20 }
       ~f:(fun sequence ->
-        sequence
-        |> Sequence.to_list
-        |> List.sort ~compare
-        |> List.stable_sort ~compare:(fun a b ->
-          Comparable.lift Int.ascending ~f:(fun t -> List.length t.rationals) a b)
-        |> List.map ~f:sexp_of_t
-        |> List.iter ~f:print_s);
+      sequence
+      |> Sequence.to_list
+      |> List.sort ~compare
+      |> List.stable_sort ~compare:(fun a b ->
+           Comparable.lift Int.ascending ~f:(fun t -> List.length t.rationals) a b)
+      |> List.map ~f:sexp_of_t
+      |> List.iter ~f:print_s);
     [%expect
       {|
       ((rationals (2.8280262305352377E-308)) (index 0))
@@ -194,6 +195,7 @@ end = struct
          2.2765450197646858E-274
          126.14432978630066
          2.716326520622772E+60))
-       (index 6)) |}]
+       (index 6))
+      |}]
   ;;
 end
